@@ -22,6 +22,11 @@ sub service { $_[0]->root->service;  }
 sub folder  { $_[0]->root->folder;   }
 sub bill    { $_[0]->root->bill;     }
 
+sub rate_limits_avail {
+    my $resp = $_[0]->root->nop;
+
+    !(!$resp->is_success && $resp->error_code =~ m/EXCEEDED_ALLOWED_CONNECTION_RATE/);
+}
 
 1; # End of t::lib::NamespaceClient
 
